@@ -62,9 +62,6 @@ INTERNALERROR_SQLCODENOTFOUND = 'InternalError.SqlCodeNotFound'
 # 内部错误。
 INTERNALERROR_STSNEWCLIENT = 'InternalError.StsNewClient'
 
-# 系统错误。
-INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
-
 # AppId资源不匹配。
 INVALIDPARAMETER_APPIDRESOURCENOTMATCH = 'InvalidParameter.AppIdResourceNotMatch'
 
@@ -137,6 +134,9 @@ INVALIDPARAMETERVALUE_RUNTYPE = 'InvalidParameterValue.RunType'
 # 不支持的复合类型。
 INVALIDPARAMETERVALUE_UNSUPPORTEDCOMPOSITE = 'InvalidParameterValue.UnSupportedComposite'
 
+# 未知停止类型错误。
+INVALIDPARAMETERVALUE_UNKNOWNSTOPTYPE = 'InvalidParameterValue.UnknownStopType'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
